@@ -26,8 +26,6 @@ import java.util.Map;
 import java.security.AccessControlContext;
 import java.security.AccessController;
 import java.security.PrivilegedAction;
-import sun.security.util.SecurityConstants;
-import jdk.internal.misc.TerminatingThreadLocal;
 import jdk.internal.reflect.CallerSensitive;
 
 /**
@@ -108,9 +106,6 @@ public class Thread implements Runnable {
 	int threadLocalRandomProbe;
 	int threadLocalRandomSecondarySeed;
 
-	/* The flag to indicate if this thread is suspended. */
-	private volatile boolean isSuspended;
-
 /**
  * 	Constructs a new Thread with no runnable object and a newly generated name.
  * The new Thread will belong to the same ThreadGroup as the Thread calling
@@ -490,22 +485,12 @@ public final void checkAccess() {
  * 	Returns the number of stack frames in this thread.
  *
  * @return		Number of stack frames
- * 
- * @exception	IllegalThreadStateException
- *					if this thread has not been suspended.
  *
  * @deprecated	The semantics of this method are poorly defined and it uses the deprecated suspend() method.
  */
 @Deprecated(forRemoval=true, since="1.2")
 public int countStackFrames() {
-	if (isAlive()) {
-		if (isSuspended) {
-			return 0;
-		}
-		throw new IllegalThreadStateException();
-	} else {
-		return 0;
-	}
+	return 0;
 }
 
 /**
@@ -558,7 +543,7 @@ public ClassLoader getContextClassLoader() {
 	if (currentManager != null) {
 		ClassLoader callerClassLoader = ClassLoader.callerClassLoader();
 		if (ClassLoader.needsClassLoaderPermissionCheck(callerClassLoader, contextClassLoader)) {
-			currentManager.checkPermission(SecurityConstants.GET_CLASSLOADER_PERMISSION);
+			currentManager.checkPermission(com.ibm.oti.util.RuntimePermissions.permissionGetClassLoader);
 		}	
 	}	
 	return contextClassLoader;
@@ -827,7 +812,6 @@ public final void resume() {
 	synchronized(lock) {
 		resumeImpl();
 	}
-	isSuspended = false;
 }
 
 /**
@@ -1057,7 +1041,7 @@ private final synchronized void stopWithThrowable(Throwable throwable) {
 	if (currentThread() != this || !(throwable instanceof ThreadDeath)) {
 		SecurityManager currentManager = System.getSecurityManager();
 		if (currentManager != null)	{
-			currentManager.checkPermission(SecurityConstants.STOP_THREAD_PERMISSION);
+			currentManager.checkPermission(com.ibm.oti.util.RuntimePermissions.permissionStopThread);
 		}
 	}
 
@@ -1108,7 +1092,6 @@ public final void suspend() {
 			suspendImpl();
 		}
 	}
-	isSuspended = true;
 }
 
 /**
@@ -1175,7 +1158,7 @@ public StackTraceElement[] getStackTrace() {
 	if (Thread.currentThread() != this) {
 		SecurityManager security = System.getSecurityManager();
 		if (security != null)
-			security.checkPermission(SecurityConstants.GET_STACK_TRACE_PERMISSION); //$NON-NLS-1$
+			security.checkPermission(com.ibm.oti.util.RuntimePermissions.permissionGetStackTrace); //$NON-NLS-1$
 	}
 	Throwable t;
 
@@ -1202,8 +1185,8 @@ public StackTraceElement[] getStackTrace() {
 public static Map<Thread, StackTraceElement[]> getAllStackTraces() {
 	SecurityManager security = System.getSecurityManager();
 	if (security != null) {
-		security.checkPermission(SecurityConstants.GET_STACK_TRACE_PERMISSION);
-		security.checkPermission(SecurityConstants.MODIFY_THREADGROUP_PERMISSION);
+		security.checkPermission(com.ibm.oti.util.RuntimePermissions.permissionGetStackTrace);
+		security.checkPermission(com.ibm.oti.util.RuntimePermissions.permissionModifyThreadGroup);
 	}
 	// Allow room for more Threads to be created before calling enumerate()
 	int count = systemThreadGroup.activeCount() + 20;
@@ -1365,10 +1348,6 @@ void uncaughtException(Throwable e) {
  * @see J9VMInternals#threadCleanup()
  */
 void cleanup() {
-	if (threadLocals != null && TerminatingThreadLocal.REGISTRY.isPresent()) {
-		TerminatingThreadLocal.threadTerminated();
-	}
-
 	group = null;
 
 	runnable = null;
