@@ -431,7 +431,7 @@ private void readObject(ObjectInputStream s)
 	
 	
 	if (suppressedExceptions != null) {
-		List<Throwable> newList = Collections.EMPTY_LIST;
+		List<Throwable> newList = Collections.EMPTY_LIST;;
 		try {
 			Module classModule = suppressedExceptions.getClass().getModule();
 			if (Object.class.getModule().equals(classModule)) {
