@@ -37,25 +37,25 @@ class VersionProps {
         "openjdk";
 
     private static final String java_version =
-        "13.0.2";
+        "13";
 
     private static final String java_version_date =
-        "2020-01-14";
+        "2019-09-17";
 
     private static final String java_runtime_name =
         "OpenJDK Runtime Environment";
 
     private static final String java_runtime_version =
-        "13.0.2+8";
+        "13+33";
 
     private static final String VERSION_NUMBER =
-        "13.0.2";
+        "13";
 
     private static final String VERSION_SPECIFICATION =
         "13";
 
     private static final String VERSION_BUILD =
-        "8";
+        "33";
 
     private static final String VERSION_PRE =
         "";
@@ -83,7 +83,7 @@ class VersionProps {
         "https://adoptopenjdk.net/";
 
     private static final String VENDOR_URL_BUG =
-        "https://github.com/AdoptOpenJDK/openjdk-support/issues";
+        "https://github.com/AdoptOpenJDK/openjdk-build/issues";
 
     /**
      * Initialize system properties using build provided values.
