@@ -147,6 +147,10 @@ module java.base {
         java.management,
         java.rmi,
         openj9.sharedclasses;
+    exports com.ibm.tools.attach.target to
+        jdk.attach,
+        jdk.jcmd,
+        jdk.management;
     exports com.sun.security.ntlm to java.security.sasl;
     exports jdk.internal to jdk.jfr;
     exports jdk.internal.access to
@@ -234,14 +238,12 @@ module java.base {
     exports jdk.internal.vm.annotation to
         jdk.internal.vm.ci,
         jdk.unsupported;
-    exports openj9.internal.management to java.management;
-    exports openj9.internal.tools.attach.target to
-        jdk.attach,
-        jdk.jcmd,
-        jdk.management;
     exports openj9.management.internal to
         java.management,
         openj9.jvm;
+    exports openj9.tools.attach.diagnostics.base to
+        jdk.attach,
+        jdk.jcmd;
     exports sun.net to
         java.net.http,
         jdk.naming.dns;
